@@ -1,6 +1,7 @@
 #ifndef GIOP_RECV_BUFFER_H
 #define GIOP_RECV_BUFFER_H 1
 
+#include <stdio.h>
 #include <orbit/GIOP/giop-types.h>
 
 #ifdef ORBIT2_INTERNAL_API
@@ -12,12 +13,6 @@ typedef enum {
   GIOP_MSG_READY
 } GIOPMessageBufferState;
 
-typedef enum {
-  GIOP_MSG_UNDERWAY,
-  GIOP_MSG_COMPLETE,
-  GIOP_MSG_INVALID
-} GIOPMessageInfo;
-
 typedef struct _GIOPMessageQueueEntry GIOPMessageQueueEntry;
 
 typedef void (*GIOPAsyncCallback) (GIOPMessageQueueEntry *ent);
@@ -58,7 +53,7 @@ struct _GIOPRecvBuffer {
 };
 
 #define         giop_msg_conversion_needed(msg)     giop_endian_conversion_needed(GIOP_MSG(msg)->header.flags)
-GIOPRecvBuffer *giop_recv_buffer_use_buf           (gboolean               is_auth);
+GIOPRecvBuffer *giop_recv_buffer_use_buf           (void);
 GIOPRecvBuffer *giop_recv_buffer_use_encaps_buf    (GIOPRecvBuffer        *buf);
 GIOPRecvBuffer *giop_recv_buffer_use_encaps        (guchar                *mem,
 						    gulong                 len);
@@ -72,17 +67,7 @@ void            giop_recv_list_setup_queue_entry_async (GIOPMessageQueueEntry *e
 
 GIOPRecvBuffer *giop_recv_buffer_get               (GIOPMessageQueueEntry *ent,
 						    gboolean               block_for_reply);
-
-GIOPRecvBuffer *giop_recv_buffer_use               (void);
 void            giop_recv_buffer_unuse             (GIOPRecvBuffer        *buf);
-GIOPMessageInfo giop_recv_buffer_state_change      (GIOPRecvBuffer        *buf,
-						    GIOPMessageBufferState state,
-						    gboolean               is_auth,
-						    GIOPConnection        *cnx);
-
-GIOPMessageInfo giop_recv_buffer_data_read         (GIOPRecvBuffer        *buf,
-						    int n, gboolean is_auth,
-						    GIOPConnection        *cnx);
 
 #define giop_recv_buffer_reply_status(buf) (                                            \
 	(buf)->msg.header.version [1] ==  2 ? (buf)->msg.u.reply_1_2.reply_status :     \
@@ -94,7 +79,8 @@ CORBA_unsigned_long         giop_recv_buffer_get_request_id (GIOPRecvBuffer *buf
 char                       *giop_recv_buffer_get_opname     (GIOPRecvBuffer *buf);
 CORBA_sequence_CORBA_octet *giop_recv_buffer_get_objkey     (GIOPRecvBuffer *buf);
 void                        giop_recv_list_zap              (GIOPConnection *cnx);
-void                        giop_dump_recv                  (GIOPRecvBuffer *recv_buffer);
+gboolean                    giop_connection_handle_input    (LINCConnection *lcnx);
+
 
 #endif /* ORBIT2_INTERNAL_API */
 
