@@ -1,26 +1,21 @@
+#ifdef G_ENABLE_DEBUG
+
 #include "config.h"
-#include <orbit/orbit.h>
+#include <unistd.h>
 #include <string.h>
+#include <sys/time.h>
+#include <ctype.h>
+#include <orbit/orbit.h>
 
 #include "orb-core-private.h"
 #include "orbit-debug.h"
 
-#ifdef TRACE_DEBUG
-#  include <unistd.h>
-#endif
-
-#ifdef TRACE_TIMING
-#  include <sys/time.h>
-#endif
-
 /*
  * Flip this switch to debug the
  * debug code.
  */
 #undef DEBUG_TRACE
 
-
-#ifdef TRACE_DEBUG
 #define NOT_NULL(str) ((str) == NULL ? "(null)" : (str))
 
 void
@@ -211,7 +206,6 @@ ORBit_trace_value (gconstpointer *val, CORBA_TypeCode tc)
 	*val = ((guchar *)*val) + ORBit_gather_alloc_info (tc);
 }
 
-#ifdef TRACE_TIMING
 void
 ORBit_trace_timestamp (void)
 {
@@ -220,7 +214,6 @@ ORBit_trace_timestamp (void)
 	gettimeofday (&t, NULL);
 	tprintf ("%lu.%lu ", t.tv_sec, t.tv_usec);
 }
-#endif
 
 void
 ORBit_trace_header (CORBA_Object   object,
@@ -262,5 +255,4 @@ ORBit_trace_profiles (CORBA_Object obj)
 	tprintf ("\n");
 }
 
-#endif /* TRACE_DEBUG */
-
+#endif /* G_ENABLE_DEBUG */
